
#line 3 "lexer.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 37
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern yy_size_t yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	yy_size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static yy_size_t yy_n_chars;		/* number of characters read into yy_ch_buf */
yy_size_t yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart (FILE *input_file  );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,yy_size_t len  );

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *yyin = (FILE *) 0, *yyout = (FILE *) 0;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 124
#define YY_END_OF_BUFFER 125
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_acclist[660] =
    {   0,
      125,  122,  124,  120,  122,  124,    1,  121,  124,  121,
      122,  124,  122,  124,  122,  124,  122,  124,  109,  122,
      124,  109,  122,  124,  122,  124,  113,  122,  124,  113,
      122,  124,  113,  122,  124,  113,  122,  124,  120,  122,
      124,  122,  124,  122,  124,  113,  122,  124,  113,  122,
      124,   29,  122,  124,    1,   30,  121,  124,   29,  121,
      122,  124,   29,  122,  124,   29,  122,  124,   29,  122,
      124,   55,  122,  124,    1,   56,  121,  124,   55,  121,
      122,  124,   47,   55,  122,  124,   55,  122,  124,   55,
      122,  124,   55,  122,  124,   53,   55,  122,  124,   54,

       55,  122,  124,   55,  122,  124,   55,  122,  124,   51,
      122,  124,    1,   52,  121,  124,   51,  121,  122,  124,
       50,   51,  122,  124,   51,  122,  124,   51,  122,  124,
       64,  122,  124,  122,  124,  113,  122,  124,  113,  122,
      124,  113,  122,  124,  117,  122,  124,   67,  122,  124,
        1,   68,  121,  124,   67,  121,  122,  124,   66,   67,
      122,  124,   67,  122,  124,   67,  122,  124,   69,  122,
      124,  122,  124,  122,  124,  122,  124,  122,  124,  113,
      122,  124,  113,  122,  124,  113,  122,  124,  113,  122,
      124,  113,  122,  124,  113,  122,  124,  113,  122,  124,

      113,  122,  124,  113,  122,  124,  113,  122,  124,  113,
      122,  124,  113,  122,  124,  118,  122,  124,  119,  122,
      124,  106,  122,  124,   48,  122,  124,  107,  122,  124,
      108,  122,  124,  122,  124,  113,  122,  124,  113,  122,
      124,  113,  122,  124,  113,  122,  124,  113,  122,  124,
      113,  122,  124,  113,  122,  124,  113,  122,  124,  113,
      122,  124,  113,  122,  124,  113,  122,  124,  113,  122,
      124,   10,  122,  124,   10,  121,  122,  124,   10,  122,
      124,   10,  122,  124,   10,  122,  124,   10,  122,  124,
       15,  122,  124,   15,  121,  122,  124,   15,  122,  124,

       15,  122,  124,   15,  122,  124,   15,  122,  124,   18,
      122,  124,   18,  121,  122,  124,   18,  122,  124,   18,
      122,  124,  109,   23,  109,  109,  112,  113,  113,  113,
      113,  113,   36,  113,  113,   28,   24,   46,   39,   49,
       25,  113,  113,  113,   65,   26,  116,  115,  113,  113,
      113,  113,  113,  113,  113,  113,  113,  113,  113,  113,
      113,  113,  113,  113,  113,  113,   27,  113,  113,  113,
      113,  113,  113,  113,  113,  113,  113,  113,  113,  113,
        9,    7,   14,   13,   11,   12,   14,   17,   16,  114,
      114,  109,    3,  109,  109,  112,  110,  111,  113,  113,

      113,  113,   31,   35,  113,  113,   44,   40,   42,   19,
       20,  113,  113,  113,   83,   21,  113,  113,  113,  113,
      113,  113,  113,   78,  113,  113,  113,  113,  113,  113,
      113,  113,  113,  113,  113,  113,  113,   22,  113,  113,
      113,  113,  113,  113,  113,  113,  113,  113,  113,  113,
      113,   12,  112,  110,  111,  113,   59,  113,  113,  113,
       38,   32,   37,   33,   34,  113,  113,   45,   41,   43,
      113,   63,  113,   62,  113,    6,  113,   81,  113,  113,
      113,  113,   73,  113,  113,   76,  113,  113,  113,  113,
      113,  113,  113,  113,  113,  113,  113,  113,   70,  113,

      113,  113,  113,   73,  113,  113,  113,  113,   94,  113,
       93,  113,  113,  113,  113,  100,  113,    8,  112,   57,
      113,   58,  113,   60,  113,  113,  113,  113,   62,  113,
       82,  113,  113,   79,  113,  113,  113,  113,  113,  113,
       77,  113,  113,  113,  113,   72,  113,  113,  113,   95,
      113,  113,  113,  113,   99,  113,  113,  113,  113,  113,
      113,  113,  113,  113,   80,  113,  113,  113,  113,  113,
       84,  113,   90,  113,   74,  113,   71,  113,  113,  113,
      113,  113,  113,  113,  113,  113,  113,  113,    4,  113,
      113,  113,  113,  113,   85,  113,  113,  113,  113,   89,

      113,  113,  113,  113,  113,   96,  113,   97,  113,  113,
      113,  113,  113,   88,  113,  113,   91,  113,   92,  113,
      113,   75,  113,  113,  113,  113,  113,  113,  113,   87,
      113,   86,  113,  113,  113,  102,  113,  113,  113,  113,
        4,    2,  104,  113,  113,  101,  113,  113,  103,  113,
      123,    5,  113,  105,  113,  113,   98,  113,   61
    } ;

static yyconst flex_int16_t yy_accept[571] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    2,    4,    7,   10,   13,
       15,   17,   19,   22,   25,   27,   30,   33,   36,   39,
       42,   44,   46,   49,   52,   55,   59,   63,   66,   69,
       72,   75,   79,   83,   87,   90,   93,   96,  100,  104,
      107,  110,  113,  117,  121,  125,  128,  131,  134,  136,
      139,  142,  145,  148,  151,  155,  159,  163,  166,  169,
      172,  174,  176,  178,  180,  183,  186,  189,  192,  195,
      198,  201,  204,  207,  210,  213,  216,  219,  222,  225,

      228,  231,  234,  236,  239,  242,  245,  248,  251,  254,
      257,  260,  263,  266,  269,  272,  275,  279,  282,  285,
      288,  291,  294,  298,  301,  304,  307,  310,  313,  317,
      320,  323,  323,  323,  324,  325,  325,  325,  326,  326,
      326,  327,  328,  329,  329,  330,  331,  332,  333,  333,
      333,  333,  333,  333,  333,  333,  333,  333,  334,  335,
      336,  337,  337,  337,  337,  337,  337,  338,  338,  339,
      339,  339,  340,  341,  342,  342,  343,  344,  345,  346,
      346,  347,  347,  348,  348,  348,  349,  350,  351,  352,
      353,  354,  355,  356,  357,  358,  359,  360,  361,  362,

      363,  364,  365,  366,  367,  368,  368,  369,  370,  371,
      372,  373,  374,  375,  376,  377,  378,  379,  380,  381,
      382,  382,  382,  382,  383,  383,  384,  384,  384,  385,
      386,  386,  388,  389,  390,  391,  391,  392,  393,  393,
      394,  395,  396,  397,  397,  398,  399,  400,  401,  402,
      403,  403,  403,  403,  403,  403,  403,  403,  404,  404,
      404,  404,  405,  405,  405,  406,  407,  407,  408,  408,
      408,  408,  409,  410,  410,  411,  411,  411,  412,  413,
      414,  415,  416,  416,  416,  417,  417,  417,  418,  419,
      420,  421,  422,  423,  424,  426,  427,  428,  429,  430,

      431,  432,  433,  434,  435,  436,  437,  438,  438,  439,
      440,  441,  442,  443,  444,  445,  446,  447,  448,  449,
      450,  451,  452,  452,  453,  453,  454,  455,  455,  456,
      456,  457,  459,  460,  461,  461,  461,  461,  462,  462,
      462,  463,  463,  464,  464,  465,  466,  466,  467,  468,
      468,  469,  470,  471,  471,  472,  474,  476,  476,  477,
      478,  480,  481,  482,  483,  485,  486,  488,  489,  490,
      491,  492,  493,  494,  495,  496,  497,  498,  499,  501,
      502,  503,  504,  506,  507,  508,  509,  511,  513,  514,
      515,  516,  518,  518,  519,  519,  519,  520,  522,  524,

      526,  526,  526,  526,  526,  526,  526,  526,  526,  527,
      528,  528,  528,  529,  531,  533,  534,  536,  537,  538,
      539,  540,  541,  543,  544,  545,  546,  548,  549,  550,
      552,  553,  554,  555,  557,  558,  559,  560,  561,  561,
      561,  561,  561,  561,  561,  561,  562,  563,  563,  563,
      564,  565,  567,  568,  569,  570,  571,  573,  575,  577,
      579,  580,  581,  582,  583,  584,  585,  586,  587,  588,
      589,  589,  589,  590,  590,  590,  590,  591,  592,  592,
      592,  593,  594,  595,  597,  598,  599,  600,  602,  603,
      604,  605,  606,  608,  610,  611,  612,  612,  612,  612,

      612,  612,  612,  613,  614,  614,  614,  616,  617,  619,
      621,  622,  624,  625,  626,  627,  628,  629,  630,  630,
      630,  630,  630,  630,  630,  630,  630,  630,  630,  630,
      632,  634,  635,  636,  638,  639,  640,  641,  641,  642,
      642,  642,  642,  642,  642,  643,  643,  645,  646,  648,
      649,  651,  651,  651,  652,  652,  652,  653,  654,  656,
      656,  656,  657,  657,  657,  659,  659,  659,  660,  660
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    4,    5,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    6,    1,    7,    8,    1,    9,    1,   10,   11,
       12,   13,    1,    1,    1,   14,   15,   16,   17,   18,
       18,   18,   18,   18,   18,   19,   19,   20,    1,   21,
        1,   22,    1,    1,   23,   23,   23,   23,   24,   23,
       25,   25,   26,   25,   25,   25,   25,   25,   25,   25,
       25,   27,   28,   25,   25,   25,   25,   25,   25,   25,
       29,   30,   31,    1,   32,    1,   33,   34,   35,   36,

       37,   38,   39,   40,   41,   42,   43,   44,   45,   46,
       47,   48,   49,   50,   51,   52,   53,   54,   55,   56,
       57,   25,   58,    1,   59,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[60] =
    {   0,
        1,    2,    3,    4,    5,    2,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    6,    6,    6,    6,    7,
        1,    1,    8,    8,    9,    9,    9,    9,    1,    1,
       10,    9,    8,    8,    8,    8,    8,    8,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    1,    1
    } ;

static yyconst flex_int16_t yy_base[604] =
    {   0,
        0,   58,   58,   65,   69,  126,   80,   85,   74,   87,
       93,  113,  179, 1361,  129,  138,  232, 1360,  100,  149,
      145,  166,  175,  187, 1367, 1370, 1370, 1370, 1370, 1336,
      185,   62,  232,  238,    0, 1345,   42,  161,   60,  239,
       63,  257,   97,   77, 1370, 1370, 1370, 1349,  216, 1335,
     1370, 1370, 1370, 1370,  176,  146,    0, 1370, 1370,  257,
     1303, 1370, 1370, 1370, 1370,    0,  256, 1370,  150,  169,
      110,  157, 1370, 1370, 1370, 1370, 1370,    0,  259, 1370,
      277,  206,  290,  294,  178,  279,  162,  190,  185,  282,
      284,  171,  222,  294,  296,  297, 1370, 1370, 1370, 1370,

     1370, 1370,  305,  301,  307,  302,  304,  220,  310,  320,
      321,  332,  316,   62,  312, 1370, 1370, 1346,  356,  327,
      361, 1370, 1370, 1345,  364,  372,  377, 1356, 1355,  357,
      379, 1347, 1346,  370, 1370, 1352,  377,  383,  389,    0,
      395, 1334, 1333, 1332,  371,  117,  378,  397,  413, 1301,
     1313,  416, 1308,  388, 1296,  373,  231, 1370,  400,  204,
     1370,    0, 1337,  377, 1336, 1335, 1370, 1341, 1370,  427,
     1297, 1370, 1370, 1370, 1339,  401,  407,  418, 1370, 1327,
     1327, 1336,  425,  431, 1307, 1308,  419,  431,  432,  433,
      425,  435,  436,  437,  446,  447,  449,  452,  450,  454,

      453,  457,  455,  460, 1370, 1333,  456,  317,  461,  462,
      467,  465,  471,  474,  475,  482,  484,  486,  487, 1370,
      510,  524,  526, 1370,  534, 1370,  536,  541,  549, 1370,
     1320, 1370, 1370, 1370, 1370, 1324, 1323,  541, 1329, 1370,
      545,    0, 1311,    0, 1310, 1309,  502,  500,  519,  511,
     1291, 1278, 1280, 1267, 1272, 1279, 1264, 1370,  518, 1288,
     1262, 1370, 1261, 1277,  513,  521, 1290, 1370, 1306, 1305,
     1304, 1370, 1370, 1310, 1370, 1277, 1308, 1370,  528,  547,
      548, 1370,  567, 1307, 1370, 1278,  564,  551,  552,  555,
      557,  564,  558,  567, 1288,  566,  565,  568,  569,  570,

      573,  574,  571,  581,  577,  587,  576, 1304, 1370,  590,
      589,  596,  591,  593,  605,  607,  610,  599,  613,  611,
      614,  615,  635, 1370,  651, 1286, 1285, 1284, 1283, 1282,
      623, 1281,  625,  629, 1267, 1246, 1261, 1370, 1260,  604,
     1370, 1248, 1370, 1259, 1370, 1370, 1240,  638,  631, 1267,
     1370, 1370, 1370, 1248,  639, 1271, 1270,  661, 1370,  641,
     1269,  645,  646,  648, 1268,  649, 1267,  650,  651,  656,
      657,  658,  653,  669,  668,  661,  665,  659, 1266,  663,
      675,  667,  689,  671,  688,  690, 1265, 1264,  693,  694,
      695, 1263,  721, 1370,  723,  728, 1262, 1261, 1260, 1259,

     1234, 1236,  136, 1226, 1228, 1216, 1236, 1239,  696,  697,
        0, 1218,  699,  698, 1250,  717, 1249,  718,  721,  722,
      725,  726, 1248,  724,  728,  729, 1247,  730,  732, 1246,
      731,  735,  736,  737,  738,  742,  746,  750, 1221, 1214,
      783, 1227, 1214, 1211, 1208,  747,  755, 1230, 1216,  751,
      763, 1224,  754,  766,  757,  758, 1223, 1222, 1212, 1201,
      776,  764,  760,  767,  773,  785,  786,  787,  791,  794,
     1173, 1168,  822, 1167,  763, 1166,  798,  796, 1191, 1149,
      797,  800,  805, 1127,  802,  806,  809, 1116,  807,  824,
      814,  815, 1097, 1091,  828,  830, 1067, 1041, 1075, 1031,

      942,  948,  849,  851,  848,  852,  967,  840,  966,  965,
      832,  964,  841,  843,  853,  850,  854,  855,  876,  877,
      976,  937,  919,  914,  889,  898,  902,  910,  878,  930,
      929,  856,  861,  921,  864,  876,  872,  932, 1370,  862,
      869,  928,  919,  936, 1370,  903,  866,  868,  498,  903,
      493,  475,  954, 1370,  945,  936, 1370,  912,  355,  245,
      952,  922,  224,  956,   81,  974,  976, 1370, 1370,  993,
     1003, 1013, 1023, 1033, 1043, 1053, 1063, 1066, 1070, 1079,
     1089, 1099, 1104, 1114, 1124, 1129, 1132, 1135, 1144, 1154,
     1164, 1174, 1179, 1189, 1198, 1200, 1204, 1208, 1216, 1220,

     1229, 1239, 1249
    } ;

static yyconst flex_int16_t yy_def[604] =
    {   0,
      569,    1,  570,  570,  571,  571,  572,  572,    1,    1,
      573,  573,    1,   13,    1,    1,    1,   17,  574,  574,
      575,  575,  576,  576,  569,  569,  569,  569,  569,  577,
      569,  569,  569,  569,  578,  579,  579,  579,  579,  569,
      569,  569,  579,  579,  569,  569,  569,  569,  569,  569,
      569,  569,  569,  569,  569,  569,  580,  569,  569,  569,
      569,  569,  569,  569,  569,  581,  569,  569,  569,  579,
      579,  579,  569,  569,  569,  569,  569,  582,  569,  569,
      569,  569,  578,  583,  579,  579,  579,  579,  579,  579,
      579,  579,  579,  579,  579,  579,  569,  569,  569,  569,

      569,  569,  569,  579,  579,  579,  579,  579,  579,  579,
      579,  579,  579,  579,  579,  569,  569,  569,  569,  569,
      569,  569,  569,  569,  569,  569,  569,  569,  569,  569,
      569,  569,  584,  569,  569,  585,  569,  569,  569,  586,
      569,  587,  579,  588,  579,  579,  579,  579,  569,  569,
      569,  569,  569,  569,  569,  569,  569,  569,  579,  579,
      569,  589,  569,  569,  569,  569,  569,  590,  569,  569,
      569,  569,  569,  569,  591,  579,  579,  579,  569,  569,
      569,  592,  569,  569,  593,  569,  579,  579,  579,  579,
      579,  579,  579,  579,  579,  579,  579,  579,  579,  579,

      579,  579,  579,  579,  569,  594,  579,  579,  579,  579,
      579,  579,  579,  579,  579,  579,  579,  579,  579,  569,
      569,  569,  569,  569,  595,  569,  569,  569,  569,  569,
      569,  569,  569,  569,  569,  569,  569,  569,  585,  569,
      569,  586,  587,  596,  597,  598,  579,  579,  579,  579,
      569,  569,  569,  569,  569,  569,  569,  569,  569,  569,
      569,  569,  569,  569,  579,  579,  569,  569,  569,  569,
      569,  569,  569,  590,  569,  569,  591,  569,  579,  579,
      579,  569,  569,  592,  569,  593,  583,  579,  579,  579,
      579,  579,  579,  579,  579,  579,  579,  579,  579,  579,

      579,  579,  579,  579,  579,  579,  579,  594,  569,  579,
      579,  579,  579,  579,  579,  579,  579,  579,  579,  579,
      579,  579,  599,  569,  569,  600,  597,  569,  598,  588,
      579,  579,  579,  579,  569,  569,  569,  569,  569,  569,
      569,  569,  569,  569,  569,  569,  569,  579,  579,  569,
      569,  569,  569,  569,  579,  579,  579,  569,  569,  579,
      579,  579,  579,  579,  579,  579,  579,  579,  579,  579,
      579,  579,  579,  579,  579,  579,  579,  579,  579,  579,
      579,  579,  579,  579,  579,  579,  579,  579,  579,  579,
      579,  579,  569,  569,  599,  569,  600,  579,  579,  579,

      569,  569,  569,  569,  569,  569,  569,  569,  579,  579,
      601,  569,  579,  579,  579,  579,  579,  579,  579,  579,
      579,  579,  579,  579,  579,  579,  579,  579,  579,  579,
      579,  579,  579,  579,  579,  579,  579,  579,  569,  569,
      569,  569,  569,  569,  569,  579,  579,  569,  569,  579,
      579,  579,  579,  579,  579,  579,  579,  579,  579,  579,
      579,  579,  579,  579,  579,  579,  579,  579,  579,  579,
      569,  569,  569,  569,  569,  569,  579,  579,  569,  569,
      579,  579,  579,  579,  579,  579,  579,  579,  579,  579,
      579,  579,  579,  579,  579,  579,  569,  569,  569,  569,

      569,  569,  579,  579,  569,  569,  579,  579,  579,  579,
      579,  579,  579,  579,  579,  579,  579,  579,  569,  569,
      602,  569,  569,  569,  569,  569,  569,  569,  569,  579,
      579,  579,  579,  579,  579,  579,  579,  602,  569,  569,
      569,  569,  569,  569,  569,  603,  579,  579,  579,  579,
      579,  569,  569,  569,  569,  603,  569,  579,  579,  569,
      569,  579,  569,  569,  579,  569,  569,  569,    0,  569,
      569,  569,  569,  569,  569,  569,  569,  569,  569,  569,
      569,  569,  569,  569,  569,  569,  569,  569,  569,  569,
      569,  569,  569,  569,  569,  569,  569,  569,  569,  569,

      569,  569,  569
    } ;

static yyconst flex_int16_t yy_nxt[1430] =
    {   0,
       26,   27,   28,   27,   29,   27,   26,   26,   26,   30,
       26,   26,   26,   31,   32,   33,   34,   34,   34,   35,
       26,   26,   36,   36,   36,   36,   36,   36,   26,   26,
       26,   36,   36,   36,   37,   36,   38,   39,   36,   36,
       36,   36,   36,   36,   36,   36,   36,   36,   36,   36,
       36,   36,   36,   36,   36,   36,   36,   26,   26,   40,
       46,  144,   47,   40,  152,   41,   42,   46,  152,   47,
       48,   52,   49,   53,  135,   54,  136,   48,   55,  144,
       68,  144,   63,   56,   64,  145,   65,   63,   69,   64,
       50,   65,   67,   68,   41,   75,  144,   76,   57,   77,

      144,   69,   28,  148,  117,   43,  153,   44,   70,   66,
       36,   71,  118,  160,   66,   75,  144,   76,  219,   77,
       79,   70,   78,   36,   71,   72,   58,   59,   52,  144,
       53,   73,   54,   60,   61,   55,  144,  441,   72,   99,
       56,  441,   78,   26,   73,   41,  159,   28,   99,  123,
      119,   28,   26,  117,  119,   57,  120,  124,  167,  177,
      168,  121,  174,   36,  175,   36,   36,  125,   28,  248,
      123,  125,   36,  126,   36,   36,  144,   28,  127,  129,
      144,  144,  163,   58,   59,   80,   97,  130,  144,   28,
      144,  129,   81,   82,  131,   97,  178,  144,   83,  130,

      134,  134,  134,  134,  144,  164,  146,   84,  191,  144,
      147,   85,  176,   86,   87,   88,   89,  152,  181,   90,
      182,  152,   91,  144,  196,   92,   93,  187,  193,   94,
       72,   95,   96,  165,  166,  192,   97,   98,  100,  144,
      149,  144,  101,  102,  149,  137,  103,  138,  138,  138,
      139,  137,  266,  141,  141,  141,  141,  152,  170,  153,
      152,  152,  170,  211,  152,  104,  105,  106,  107,  108,
      263,  197,   90,  263,  198,   91,  109,  110,  111,  112,
      264,  563,  113,  114,   95,  115,  150,  140,  151,  154,
      180,  155,  134,  134,  134,  134,  156,  171,  144,  153,

      153,  144,  153,  144,  157,  183,  183,  183,  183,  184,
      184,  184,  184,  144,  158,  144,  144,  205,  188,  206,
      144,  144,  189,  144,  186,  190,  144,  194,  152,  144,
      195,  144,  152,  199,  200,  144,  144,  203,  209,  144,
      144,  202,  212,  204,  207,  201,  188,  208,  191,  210,
      213,  144,  214,  190,  216,  199,  218,  221,  204,  233,
      215,  221,  223,  224,  217,  227,  225,  201,  222,  227,
      153,  234,  311,  152,  144,  220,  228,  152,  229,  230,
      152,  233,  229,  269,  152,  238,  238,  238,  238,  231,
      144,  232,  241,  241,  241,  241,  137,  144,  138,  138,

      138,  139,  137,  247,  139,  139,  139,  139,  137,  260,
      141,  141,  141,  141,  149,  153,  144,  152,  149,  144,
      144,  152,  153,  254,  261,  255,  144,  249,  170,  250,
      262,  256,  170,  279,  270,  271,  265,  144,  144,  257,
      183,  183,  183,  183,  144,  258,  184,  184,  184,  184,
      144,  144,  144,  280,  144,  144,  144,  288,  281,  153,
      150,  186,  151,  289,  290,  144,  144,  171,  144,  144,
      153,  144,  144,  144,  144,  144,  144,  292,  291,  144,
      144,  144,  294,  297,  144,  300,  144,  293,  295,  298,
      144,  296,  302,  144,  144,  299,  301,  304,  312,  314,

      307,  144,  303,  144,  306,  144,  144,  305,  310,  318,
      560,  221,  144,  294,  313,  221,  316,  144,  317,  144,
      315,  144,  222,  319,  321,  223,  224,  223,  224,  225,
      144,  223,  144,  320,  322,  223,  224,  227,  144,  223,
      144,  227,  229,  230,  332,  348,  229,  144,  228,  334,
      325,  230,  331,  231,  325,  324,  238,  238,  238,  238,
      241,  241,  241,  241,  342,  333,  144,  144,  358,  359,
      144,  144,  358,  349,  144,  343,  144,  144,  355,  184,
      184,  184,  184,  144,  144,  144,  144,  144,  144,  144,
      144,  356,  144,  144,  186,  144,  144,  364,  357,  366,

      144,  361,  365,  360,  367,  362,  144,  363,  144,  144,
      144,  379,  144,  372,  368,  144,  370,  377,  144,  374,
      371,  369,  373,  375,  144,  381,  144,  376,  382,  144,
      144,  384,  144,  144,  144,  383,  393,  394,  378,  380,
      393,  388,  144,  390,  144,  385,  387,  386,  144,  389,
      144,  392,  325,  230,  396,  405,  325,  144,  144,  391,
      144,  258,  358,  359,  144,  144,  358,  144,  144,  144,
      144,  410,  144,  398,  399,  144,  144,  144,  144,  400,
      144,  409,  144,  419,  144,  413,  144,  144,  144,  357,
      144,  416,  420,  421,  144,  414,  430,  415,  422,  418,

      417,  424,  426,  428,  423,  425,  427,  144,  144,  144,
      431,  429,  144,  144,  144,  144,  144,  144,  144,  432,
      433,  434,  393,  394,  393,  394,  393,  437,  393,  393,
      394,  425,  435,  393,  436,  450,  144,  144,  438,  446,
      144,  144,  396,  144,  144,  144,  447,  144,  144,  144,
      144,  144,  451,  452,  144,  144,  144,  144,  453,  456,
      457,  144,  463,  459,  462,  144,  144,  458,  466,  144,
      144,  455,  454,  144,  144,  461,  144,  144,  464,  144,
      460,  470,  144,  144,  441,  144,  144,  465,  441,  483,
      467,  478,  144,  477,  468,  144,  481,  469,  473,  473,

      473,  473,  484,  482,  144,  144,  144,  488,  485,  486,
      144,  489,  487,  144,  501,  144,  144,  144,  490,  144,
      262,  144,  495,  499,  144,  144,  144,  499,  144,  491,
      493,  494,  503,  144,  144,  508,  492,  473,  473,  473,
      473,  509,  511,  144,  512,  496,  504,  144,  507,  144,
      525,  144,  526,  529,  525,  514,  526,  529,  510,  144,
      144,  515,  144,  513,  527,  528,  528,  531,  144,  144,
      144,  516,  144,  144,  144,  144,  530,  525,  526,  517,
      144,  525,  526,  144,  546,  144,  518,  144,  532,  534,
      525,  144,  547,  548,  525,  144,  533,  535,  546,  526,

      549,  552,  537,  526,  542,  542,  542,  542,  551,  557,
      536,  558,  254,  543,  543,  543,  543,  544,  544,  544,
      544,  545,  144,  550,  557,  544,  544,  544,  544,  553,
      554,  144,  555,  553,  543,  543,  543,  543,  539,  559,
      144,  144,  557,  542,  542,  542,  542,  545,  144,  144,
      541,  544,  544,  544,  544,  553,  554,  557,  565,  553,
      561,  561,  561,  561,  562,  564,  261,  561,  561,  561,
      561,  566,  566,  566,  566,  567,  568,  567,  568,  567,
      540,  567,  539,  144,  144,  144,  144,  524,  523,  566,
      566,  566,  566,   45,   45,   45,   45,   45,   45,   45,

       45,   45,   45,   51,   51,   51,   51,   51,   51,   51,
       51,   51,   51,   62,   62,   62,   62,   62,   62,   62,
       62,   62,   62,   74,   74,   74,   74,   74,   74,   74,
       74,   74,   74,  116,  116,  116,  116,  116,  116,  116,
      116,  116,  116,  122,  122,  122,  122,  122,  122,  122,
      122,  122,  122,  128,  128,  128,  128,  128,  128,  128,
      128,  128,  128,  132,  132,  522,  132,  132,  132,  132,
      132,  132,  132,  142,  142,  143,  143,  143,  143,  169,
      169,  521,  169,  169,  169,  169,  169,  169,  169,  173,
      173,  520,  173,  173,  173,  173,  173,  173,  173,  179,

      179,  519,  179,  179,  179,  179,  179,  179,  179,  185,
      144,  185,  185,  185,  236,  236,  144,  236,  236,  236,
      236,  236,  236,  236,  239,  239,  239,  239,  239,  239,
      239,  239,  239,  239,  242,  144,  242,  243,  243,  243,
      243,  246,  246,  246,  267,  267,  144,  267,  267,  267,
      267,  267,  267,  267,  274,  274,  274,  274,  274,  274,
      274,  274,  274,  274,  277,  277,  277,  277,  277,  277,
      277,  277,  277,  277,  284,  284,  284,  284,  284,  284,
      284,  284,  284,  284,  286,  506,  286,  286,  286,  308,
      308,  308,  308,  308,  308,  308,  308,  308,  308,  323,

      323,  505,  502,  500,  498,  323,  323,  326,  326,  327,
      327,  327,  327,  329,  329,  329,  329,  395,  395,  497,
      144,  395,  395,  395,  395,  397,  397,  397,  397,  448,
      448,  144,  448,  448,  448,  448,  448,  448,  448,  538,
      538,  144,  144,  144,  538,  538,  538,  538,  538,  556,
      556,  480,  556,  479,  556,  556,  556,  556,  556,  476,
      475,  257,  474,  472,  471,  144,  144,  144,  144,  144,
      449,  445,  444,  343,  443,  442,  440,  439,  144,  144,
      144,  244,  144,  144,  144,  144,  144,  144,  144,  144,
      144,  412,  411,  408,  407,  406,  404,  403,  402,  401,

      144,  569,  330,  245,  328,  244,  309,  144,  186,  285,
      278,  354,  275,  353,  352,  351,  350,  347,  346,  345,
      344,  341,  340,  339,  338,  337,  336,  335,  330,  328,
      244,  240,  235,  235,  324,  309,  287,  186,  285,  283,
      282,  278,  276,  275,  273,  272,  268,  259,  253,  252,
      251,  245,  144,  244,  240,  237,  235,  233,  233,  226,
      220,  172,  162,  161,  144,  133,  569,   41,   41,   25,
      569,  569,  569,  569,  569,  569,  569,  569,  569,  569,
      569,  569,  569,  569,  569,  569,  569,  569,  569,  569,
      569,  569,  569,  569,  569,  569,  569,  569,  569,  569,

      569,  569,  569,  569,  569,  569,  569,  569,  569,  569,
      569,  569,  569,  569,  569,  569,  569,  569,  569,  569,
      569,  569,  569,  569,  569,  569,  569,  569,  569
    } ;

static yyconst flex_int16_t yy_chk[1430] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    2,
        3,   37,    3,    2,   41,    2,    2,    4,   41,    4,
        3,    5,    4,    5,   32,    5,   32,    4,    5,   39,
        9,  114,    7,    5,    7,   37,    7,    8,    9,    8,
        4,    8,    8,   10,   10,   11,   44,   11,    5,   11,

      565,   10,   19,   39,   19,    2,   41,    2,    9,    7,
        9,    9,   19,   44,    8,   12,   43,   12,  114,   12,
       12,   10,   11,   10,   10,    9,    5,    5,    6,   71,
        6,    9,    6,    6,    6,    6,  146,  403,   10,   15,
        6,  403,   12,   15,   10,   16,   43,   21,   16,   21,
       20,   20,   16,   20,   20,    6,   20,   21,   56,   71,
       56,   20,   69,   15,   69,   15,   15,   22,   22,  146,
       22,   22,   16,   22,   16,   16,   72,   23,   22,   23,
       38,   87,   55,    6,    6,   13,   15,   23,   70,   24,
       92,   24,   13,   13,   24,   16,   72,   85,   13,   24,

       31,   31,   31,   31,   89,   55,   38,   13,   87,   88,
       38,   13,   70,   13,   13,   13,   13,   49,   82,   13,
       82,   49,   13,  160,   92,   13,   13,   85,   89,   13,
       13,   13,   13,   55,   55,   88,   13,   13,   17,  108,
       40,   93,   17,   17,   40,   33,   17,   33,   33,   33,
       33,   34,  160,   34,   34,   34,   34,   67,   60,   49,
       79,   67,   60,  108,   79,   17,   17,   17,   17,   17,
      157,   93,   17,  563,   93,   17,   17,   17,   17,   17,
      157,  560,   17,   17,   17,   17,   40,   33,   40,   42,
       81,   42,   81,   81,   81,   81,   42,   60,   86,   67,

       60,   90,   79,   91,   42,   83,   83,   83,   83,   84,
       84,   84,   84,   94,   42,   95,   96,  103,   86,  103,
      104,  106,   86,  107,   84,   86,  105,   90,  120,  109,
       91,  115,  120,   94,   94,  113,  208,   96,  106,  110,
      111,   95,  109,   96,  104,   94,  105,  104,  106,  107,
      109,  112,  110,  105,  111,  113,  113,  119,  115,  130,
      110,  119,  121,  121,  112,  125,  121,  113,  119,  125,
      120,  130,  208,  126,  559,  121,  125,  126,  127,  127,
      131,  131,  127,  164,  131,  134,  134,  134,  134,  127,
      145,  127,  137,  137,  137,  137,  138,  147,  138,  138,

      138,  138,  139,  145,  139,  139,  139,  139,  141,  156,
      141,  141,  141,  141,  149,  126,  148,  152,  149,  159,
      176,  152,  131,  154,  156,  154,  177,  147,  170,  148,
      156,  154,  170,  176,  164,  164,  159,  178,  187,  154,
      183,  183,  183,  183,  191,  154,  184,  184,  184,  184,
      188,  189,  190,  177,  192,  193,  194,  187,  178,  152,
      149,  184,  149,  188,  189,  195,  196,  170,  197,  199,
      170,  198,  201,  200,  203,  207,  202,  191,  190,  204,
      209,  210,  193,  196,  212,  198,  211,  192,  194,  197,
      213,  195,  200,  214,  215,  197,  199,  202,  209,  211,

      204,  216,  201,  217,  203,  218,  219,  202,  207,  215,
      552,  221,  551,  211,  210,  221,  213,  549,  214,  248,
      212,  247,  221,  216,  218,  222,  222,  223,  223,  222,
      250,  223,  265,  217,  219,  225,  225,  227,  249,  225,
      266,  227,  228,  228,  248,  265,  228,  279,  227,  250,
      229,  229,  247,  228,  229,  228,  238,  238,  238,  238,
      241,  241,  241,  241,  259,  249,  280,  281,  283,  283,
      288,  289,  283,  266,  290,  259,  291,  293,  279,  287,
      287,  287,  287,  292,  297,  296,  294,  298,  299,  300,
      303,  280,  301,  302,  287,  307,  305,  292,  281,  294,

      304,  289,  293,  288,  296,  290,  306,  291,  311,  310,
      313,  307,  314,  300,  297,  312,  299,  305,  318,  302,
      299,  298,  301,  303,  315,  311,  316,  304,  312,  317,
      320,  314,  319,  321,  322,  313,  323,  323,  306,  310,
      323,  318,  331,  320,  333,  315,  317,  316,  334,  319,
      349,  322,  325,  325,  323,  340,  325,  348,  355,  321,
      360,  340,  358,  358,  362,  363,  358,  364,  366,  368,
      369,  349,  373,  331,  333,  370,  371,  372,  378,  334,
      376,  348,  380,  369,  377,  360,  382,  375,  374,  355,
      384,  364,  370,  371,  381,  362,  380,  363,  372,  368,

      366,  374,  375,  377,  373,  374,  376,  385,  383,  386,
      381,  378,  389,  390,  391,  409,  410,  414,  413,  382,
      383,  384,  393,  393,  395,  395,  393,  389,  395,  396,
      396,  391,  385,  396,  386,  413,  416,  418,  390,  409,
      419,  420,  395,  424,  421,  422,  410,  425,  426,  428,
      431,  429,  414,  416,  432,  433,  434,  435,  418,  421,
      422,  436,  431,  425,  429,  437,  446,  424,  434,  438,
      450,  420,  419,  453,  447,  428,  455,  456,  432,  463,
      426,  438,  451,  462,  441,  454,  464,  433,  441,  453,
      435,  447,  465,  446,  436,  461,  450,  437,  441,  441,

      441,  441,  454,  451,  466,  467,  468,  462,  455,  456,
      469,  463,  461,  470,  475,  478,  481,  477,  464,  482,
      475,  485,  469,  473,  483,  486,  489,  473,  487,  465,
      467,  468,  477,  491,  492,  482,  466,  473,  473,  473,
      473,  483,  486,  490,  487,  470,  478,  495,  481,  496,
      503,  511,  504,  506,  503,  490,  504,  506,  485,  508,
      513,  491,  514,  489,  505,  505,  505,  511,  503,  516,
      504,  492,  515,  517,  518,  532,  508,  519,  520,  495,
      533,  519,  520,  535,  529,  547,  496,  548,  513,  515,
      525,  537,  532,  533,  525,  536,  514,  516,  529,  526,

      535,  541,  518,  526,  525,  525,  525,  525,  537,  546,
      517,  548,  540,  526,  526,  526,  526,  527,  527,  527,
      527,  528,  550,  536,  546,  528,  528,  528,  528,  542,
      542,  558,  543,  542,  543,  543,  543,  543,  538,  550,
      534,  562,  556,  542,  542,  542,  542,  544,  531,  530,
      524,  544,  544,  544,  544,  553,  553,  556,  562,  553,
      555,  555,  555,  555,  558,  561,  523,  561,  561,  561,
      561,  564,  564,  564,  564,  566,  566,  567,  567,  566,
      522,  567,  521,  512,  510,  509,  507,  502,  501,  566,
      566,  566,  566,  570,  570,  570,  570,  570,  570,  570,

      570,  570,  570,  571,  571,  571,  571,  571,  571,  571,
      571,  571,  571,  572,  572,  572,  572,  572,  572,  572,
      572,  572,  572,  573,  573,  573,  573,  573,  573,  573,
      573,  573,  573,  574,  574,  574,  574,  574,  574,  574,
      574,  574,  574,  575,  575,  575,  575,  575,  575,  575,
      575,  575,  575,  576,  576,  576,  576,  576,  576,  576,
      576,  576,  576,  577,  577,  500,  577,  577,  577,  577,
      577,  577,  577,  578,  578,  579,  579,  579,  579,  580,
      580,  499,  580,  580,  580,  580,  580,  580,  580,  581,
      581,  498,  581,  581,  581,  581,  581,  581,  581,  582,

      582,  497,  582,  582,  582,  582,  582,  582,  582,  583,
      494,  583,  583,  583,  584,  584,  493,  584,  584,  584,
      584,  584,  584,  584,  585,  585,  585,  585,  585,  585,
      585,  585,  585,  585,  586,  488,  586,  587,  587,  587,
      587,  588,  588,  588,  589,  589,  484,  589,  589,  589,
      589,  589,  589,  589,  590,  590,  590,  590,  590,  590,
      590,  590,  590,  590,  591,  591,  591,  591,  591,  591,
      591,  591,  591,  591,  592,  592,  592,  592,  592,  592,
      592,  592,  592,  592,  593,  480,  593,  593,  593,  594,
      594,  594,  594,  594,  594,  594,  594,  594,  594,  595,

      595,  479,  476,  474,  472,  595,  595,  596,  596,  597,
      597,  597,  597,  598,  598,  598,  598,  599,  599,  471,
      460,  599,  599,  599,  599,  600,  600,  600,  600,  601,
      601,  459,  601,  601,  601,  601,  601,  601,  601,  602,
      602,  458,  457,  452,  602,  602,  602,  602,  602,  603,
      603,  449,  603,  448,  603,  603,  603,  603,  603,  445,
      444,  443,  442,  440,  439,  430,  427,  423,  417,  415,
      412,  408,  407,  406,  405,  404,  402,  401,  400,  399,
      398,  397,  392,  388,  387,  379,  367,  365,  361,  357,
      356,  354,  350,  347,  344,  342,  339,  337,  336,  335,

      332,  330,  329,  328,  327,  326,  308,  295,  286,  284,
      277,  276,  274,  271,  270,  269,  267,  264,  263,  261,
      260,  257,  256,  255,  254,  253,  252,  251,  246,  245,
      243,  239,  237,  236,  231,  206,  186,  185,  182,  181,
      180,  175,  171,  168,  166,  165,  163,  155,  153,  151,
      150,  144,  143,  142,  136,  133,  132,  129,  128,  124,
      118,   61,   50,   48,   36,   30,   25,   18,   14,  569,
      569,  569,  569,  569,  569,  569,  569,  569,  569,  569,
      569,  569,  569,  569,  569,  569,  569,  569,  569,  569,
      569,  569,  569,  569,  569,  569,  569,  569,  569,  569,

      569,  569,  569,  569,  569,  569,  569,  569,  569,  569,
      569,  569,  569,  569,  569,  569,  569,  569,  569,  569,
      569,  569,  569,  569,  569,  569,  569,  569,  569
    } ;

extern int yy_flex_debug;
int yy_flex_debug = 0;

static yy_state_type *yy_state_buf=0, *yy_state_ptr=0;
static char *yy_full_match;
static int yy_lp;
#define REJECT \
{ \
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */ \
yy_cp = (yy_full_match); /* restore poss. backed-over text */ \
++(yy_lp); \
goto find_rule; \
}

#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "lexer.l"
/* GOB C Preprocessor
 * Copyright (C) 1999-2000 the Free Software Foundation.
 * Copyright (C) 2000 Eazel, Inc.
 * Copyright (C) 2001-2011 George (Jiri) Lebl
 *
 * Author: George Lebl
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the  Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 * USA.
 */
#line 24 "lexer.l"

#include "config.h" 
#include <stdlib.h>
#include <string.h>
#include <ctype.h>
#include <glib.h>

#include "treefuncs.h"
#include "parse.h"
#include "main.h"
#include "util.h"

static int parenth_depth = 0;
static int before_comment
/* New flex is on drugs */
#if defined(FLEX_SCANNER) && ! defined(INITIAL)
	= 0;
#else
	= INITIAL;
#endif
static gboolean class_after_c = FALSE;
static int code_type = CCODE;
static int before_string;
static int property_paren_depth = 0;

/* GTK+ doc stuff */
static char *gtk_doc_func = NULL; /* current gtk-doc func */
GHashTable *gtk_doc_hash = NULL;

static GString *cbuf = NULL;
int ccode_line = 1;

GList *include_files = NULL;
/* 0 no, 1 means yes, 2+ means don't even start looking anymore */
static int look_for_includes = 0;

int line_no = 1;
/* last filename parsed from a #line directive */
char *hline_filename = NULL;

static void
clear_cbuf(void)
{
	if(!cbuf) {
		cbuf = g_string_new(NULL);
	} else {
		cbuf = g_string_assign(cbuf, "");
	}
}

static void
add_to_cbuf(char *s)
{
	if(!cbuf) {
		cbuf = g_string_new(s);
	} else {
		cbuf = g_string_append(cbuf,s);
	}
}

static void
add_gtk_doc_func(void)
{
	if(!gtk_doc_func)
		return;

	if(!gtk_doc_hash)
		gtk_doc_hash = g_hash_table_new(g_str_hash, g_str_equal);
	g_hash_table_insert(gtk_doc_hash, gtk_doc_func, g_strdup(cbuf->str));
	clear_cbuf();

	gtk_doc_func = NULL;
}

/* Ugly warning / error avoidings */
#ifdef FLEX_SCANNER
int yylex(void);
int yywrap(void) { return 1; }
#endif












#line 1154 "lexer.c"

#define INITIAL 0
#define COMMENT 1
#define C_CODE 2
#define CODE_STRING 3
#define CLASS_CODE 4
#define CLASS_STRING 5
#define CLASS_CODE_I 6
#define PROPERTY_CODE 7
#define PROPERTY_CODE_I 8
#define GTK_DOC_BEFORE_NAME 9
#define GTK_DOC 10
#define GTK_DOC_LINE 11

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy (void );

int yyget_debug (void );

void yyset_debug (int debug_flag  );

YY_EXTRA_TYPE yyget_extra (void );

void yyset_extra (YY_EXTRA_TYPE user_defined  );

FILE *yyget_in (void );

void yyset_in  (FILE * in_str  );

FILE *yyget_out (void );

void yyset_out  (FILE * out_str  );

yy_size_t yyget_leng (void );

char *yyget_text (void );

int yyget_lineno (void );

void yyset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	if ( yyleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(yytext[yyleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 120 "lexer.l"



/* Avoid warning from flex, cuz flex sucks */
#ifdef FLEX_SCANNER
yy_current_state = 0;
#endif



#line 1361 "lexer.c"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

        /* Create the reject buffer large enough to save one state per allowed character. */
        if ( ! (yy_state_buf) )
            (yy_state_buf) = (yy_state_type *)yyalloc(YY_STATE_BUF_SIZE  );
            if ( ! (yy_state_buf) )
                YY_FATAL_ERROR( "out of dynamic memory in yylex()" );

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE );
		}

		yy_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();

		(yy_state_ptr) = (yy_state_buf);
		*(yy_state_ptr)++ = yy_current_state;

yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 570 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			*(yy_state_ptr)++ = yy_current_state;
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1370 );

yy_find_action:
		yy_current_state = *--(yy_state_ptr);
		(yy_lp) = yy_accept[yy_current_state];
find_rule: /* we branch to this label when backing up */
		for ( ; ; ) /* until we find what rule we matched */
			{
			if ( (yy_lp) && (yy_lp) < yy_accept[yy_current_state + 1] )
				{
				yy_act = yy_acclist[(yy_lp)];
					{
					(yy_full_match) = yy_cp;
					break;
					}
				}
			--yy_cp;
			yy_current_state = *--(yy_state_ptr);
			(yy_lp) = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 130 "lexer.l"
{ line_no++; REJECT; }
	YY_BREAK
case 2:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 132 "lexer.l"
{
/* Thy evil easter egg */
#define QQ(x) long x
#define KK(x) =atoi(__(&,,x,))
#define MM(x,a) {QQ(i);for(i=2;i<x;i++){a}}
#define PP(Q) (P%Q)==0
#define ___(x,y,z) if(x z y)
#define __(a,x,y,z) a(yytext[y] x z)
#define O__O(a,b) fprintf(stderr,"%s is %s!\n",a,b)
QQ(m)=1;___(__(,==,2,'P'),__(,==,5,'M'),&&
){QQ(P)KK(8);MM(P,___(PP(i),,)m=0;)}__(,=,
7,0);___(,,m){O__O(__( &,,8,),__(&,,2,));}
#undef QQ
#undef KK
#undef MM
#undef PP
#undef ___
#undef __
#undef O__O
REJECT;
}
	YY_BREAK
case 3:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 154 "lexer.l"
{ ; /*comment, ignore*/ }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 156 "lexer.l"
{
	char *p;
	char *number;
	char *filename;
	char *str=g_strdup(yytext);

	/* find first digit of line number */
	p=str;
	while(*p&&!isdigit(*p)) p++;
	number=p;
  
	/* find end of line number */
	while(*p&&isdigit(*p)) p++;
	if(*p) *p++=0;

	/* find beginning of filename */
	p=strchr(p,'"');
	if(p) p++;
	filename=p;

	/* find end of filename */
	if(p) p=strchr(p,'"');
	if(p) *p=0;

	/* stash number (minus one because we don't count this line) */  
	if(number) line_no=atoi(number)-1;

	/* stash filename */
	if(filename) {
		if(hline_filename) g_free(hline_filename);
		hline_filename=g_strdup(filename);
	}
  
	/* clean up */
	g_free(str);
}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 193 "lexer.l"
{
	if(look_for_includes==1) {
		char *p;
		char *file;
		char *str = g_strdup(yytext);
		file = strchr(str,'"');
		if(!file) file = strchr(str,'<');
		file++;
		p = strchr(file,'"');
		if(!p) p = strchr(file,'>');
		if (p != NULL) {
			*p = '\0';
			include_files = g_list_prepend(include_files,g_strdup(file));
			g_free(str);
		}
	}
	REJECT;
}
	YY_BREAK
case 6:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 212 "lexer.l"
{
			/* eat out gtk doc stuff */
			BEGIN(GTK_DOC_BEFORE_NAME);
			clear_cbuf();
		}
	YY_BREAK
case 7:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 217 "lexer.l"
{
			/* empty doc lines */
			;
		}	
	YY_BREAK
case 8:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 221 "lexer.l"
{
			char *p;
			BEGIN(GTK_DOC);
			p = strchr(yytext, '*');
			g_free(gtk_doc_func);
			gtk_doc_func = g_strdup(p+2);
			p = strchr(gtk_doc_func, ':');
			if(p) *p='\0';
			g_strstrip(gtk_doc_func);
		}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 231 "lexer.l"
{
			BEGIN(CLASS_CODE_I);
		}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 234 "lexer.l"
{
			BEGIN(COMMENT);
			before_comment = CLASS_CODE_I;
		}
	YY_BREAK
case 11:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 238 "lexer.l"
{
			/* empty doc lines */
			add_to_cbuf(" *\n");
		}	
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 242 "lexer.l"
{
			BEGIN(CLASS_CODE_I);
			add_gtk_doc_func();
		}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 246 "lexer.l"
{
			fflush(stdout);
			add_to_cbuf(" * ");
			BEGIN(GTK_DOC_LINE);
		}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 251 "lexer.l"
{
			BEGIN(CLASS_CODE_I);
		}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 254 "lexer.l"
{
			BEGIN(COMMENT);
			before_comment = CLASS_CODE_I;
		}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 258 "lexer.l"
{
			BEGIN(CLASS_CODE_I);
			add_to_cbuf("\n");
			add_gtk_doc_func();
		}
	YY_BREAK
case 17:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 263 "lexer.l"
{
			BEGIN(GTK_DOC);
			add_to_cbuf(yytext);
			add_to_cbuf("\n");
		}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 268 "lexer.l"
{
			fflush(stdout);
			add_to_cbuf(yytext);
		}
	YY_BREAK
case 19:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 273 "lexer.l"
{ add_to_cbuf(yytext); /*comment, ignore*/ }
	YY_BREAK
case 20:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 274 "lexer.l"
{ ; /*comment, ignore*/ }
	YY_BREAK
case 21:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 275 "lexer.l"
{ ; /*comment, ignore*/ }
	YY_BREAK
case 22:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 276 "lexer.l"
{ ; /*comment, ignore*/ }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 277 "lexer.l"
{BEGIN(COMMENT); before_comment = INITIAL; }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 278 "lexer.l"
{
	add_to_cbuf(yytext);
	BEGIN(COMMENT);
	before_comment = C_CODE;
}
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 283 "lexer.l"
{BEGIN(COMMENT); before_comment = CLASS_CODE; }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 284 "lexer.l"
{BEGIN(COMMENT); before_comment = CLASS_CODE_I; }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 285 "lexer.l"
{BEGIN(COMMENT); before_comment = PROPERTY_CODE_I; }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 286 "lexer.l"
{
	if(before_comment == C_CODE) add_to_cbuf(yytext);
	BEGIN(before_comment);
		}
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 290 "lexer.l"
{
	/* comment, ignore */
	if(before_comment == C_CODE) add_to_cbuf(yytext);
		}
	YY_BREAK
case 30:
/* rule 30 can match eol */
YY_RULE_SETUP
#line 294 "lexer.l"
{
	/* comment, ignore */
	if(before_comment == C_CODE) add_to_cbuf(yytext);
		}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 299 "lexer.l"
{
			BEGIN(C_CODE);
			parenth_depth = 1;
			class_after_c = FALSE;
			code_type = ACODE;
			clear_cbuf();
			ccode_line = line_no;
		}
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 307 "lexer.l"
{
			BEGIN(C_CODE);
			parenth_depth = 1;
			class_after_c = FALSE;
			code_type = ATCODE;
			clear_cbuf();
			ccode_line = line_no;
		}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 316 "lexer.l"
{
			BEGIN(C_CODE);
			parenth_depth = 1;
			class_after_c = FALSE;
			code_type = HTCODE;
			clear_cbuf();
			ccode_line = line_no;
		}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 324 "lexer.l"
{
			BEGIN(C_CODE);
			parenth_depth = 1;
			class_after_c = FALSE;
			code_type = PHCODE;
			clear_cbuf();
			ccode_line = line_no;
		}
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 332 "lexer.l"
{
			BEGIN(C_CODE);
			parenth_depth = 1;
			class_after_c = FALSE;
			code_type = HCODE;
			clear_cbuf();
			ccode_line = line_no;
		}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 340 "lexer.l"
{
			BEGIN(C_CODE);
			parenth_depth = 1;
			class_after_c = FALSE;
			code_type = CCODE;
			clear_cbuf();
			ccode_line = line_no;
			if(look_for_includes==0)
				look_for_includes=1;
		}
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 350 "lexer.l"
{
			BEGIN(C_CODE);
			parenth_depth = 1;
			class_after_c = FALSE;
			code_type = CTCODE;
			clear_cbuf();
			ccode_line = line_no;
			if(look_for_includes==0)
				look_for_includes=1;
		}
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 360 "lexer.l"
{
			BEGIN(C_CODE);
			parenth_depth = 1;
			class_after_c = FALSE;
			code_type = ADCODE;
			clear_cbuf();
			ccode_line = line_no;
		}
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 368 "lexer.l"
{
			BEGIN(INITIAL);
			yylval.cbuf = cbuf;
			cbuf = NULL;
			if(look_for_includes==1)
				look_for_includes=0;
			return code_type;
		}
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 377 "lexer.l"
{ add_to_cbuf(yytext); }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 378 "lexer.l"
{ add_to_cbuf(yytext); }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 379 "lexer.l"
{ add_to_cbuf(yytext); }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 380 "lexer.l"
{ add_to_cbuf(yytext); }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 381 "lexer.l"
{ add_to_cbuf(yytext); }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 382 "lexer.l"
{ add_to_cbuf(yytext); }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 384 "lexer.l"
{ add_to_cbuf(yytext); }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 387 "lexer.l"
{
			BEGIN(CODE_STRING);
			before_string = C_CODE;
			add_to_cbuf(yytext);
		}
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 392 "lexer.l"
{
			BEGIN(CODE_STRING);
			before_string = PROPERTY_CODE_I;
			add_to_cbuf(yytext);
		}
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 397 "lexer.l"
{ add_to_cbuf(yytext); }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 398 "lexer.l"
{
			BEGIN(before_string);
			add_to_cbuf(yytext);
			if (before_string == PROPERTY_CODE_I) {
				yylval.id = cbuf->str;
				g_string_free (cbuf, FALSE);
				cbuf = NULL;
				return STRING;
			}
		}
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 408 "lexer.l"
{ add_to_cbuf(yytext); }
	YY_BREAK
case 52:
/* rule 52 can match eol */
YY_RULE_SETUP
#line 409 "lexer.l"
{ add_to_cbuf(yytext); }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 411 "lexer.l"
{
			parenth_depth++;
			add_to_cbuf(yytext);
		}
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 415 "lexer.l"
{
			parenth_depth--;
			if(parenth_depth<0) {
				REJECT;
			} else if(parenth_depth==0 && class_after_c) {
				BEGIN(CLASS_CODE_I);
				yylval.cbuf = cbuf;
				cbuf = NULL;
				return CCODE;
			}
			add_to_cbuf(yytext);
		}
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 428 "lexer.l"
{ add_to_cbuf(yytext); }
	YY_BREAK
case 56:
/* rule 56 can match eol */
YY_RULE_SETUP
#line 429 "lexer.l"
{ add_to_cbuf(yytext); }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 431 "lexer.l"
{
			static int found_classes = 0;
			look_for_includes = 2;
			BEGIN(CLASS_CODE);

			if(++found_classes > 1) {
				error_print(GOB_ERROR, line_no,
					    "Only one class per file allowed");
			}

			return CLASS;
		}
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 444 "lexer.l"
{ return ERROR; }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 445 "lexer.l"
{ return ENUM; }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 446 "lexer.l"
{ return FLAGS; }
	YY_BREAK
case 61:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 448 "lexer.l"
{
			int maj = 0, min = 0, pl = 0;
			int rmaj = 0, rmin = 0, rpl = 0;
			int effective_maj = 0;
			int effective_rmaj = 0;
			char *p;
			
			sscanf (VERSION, "%d.%d.%d", &rmaj, &rmin, &rpl);
			effective_rmaj = rmaj;
			if (rmin >= 90)
				effective_rmaj = rmaj + 1;

			p = strchr (yytext,'r');
			g_assert (p); /* we MUST have found it */
			sscanf (p, "requires %d.%d.%d", &maj, &min, &pl);
			effective_maj = maj;
			if (min >= 90)
				effective_maj = maj + 1;

			if(rmaj < maj ||
			   (rmaj == maj && rmin < min) ||
			   (rmaj == maj && rmin == min && rpl < pl)) {
				error_printf (GOB_ERROR, line_no,
					      "GOB version at least %d.%d.%d required "
					      "(this is %s)\n"
					      "To upgrade your gob, see: "
					      "http://www.5z.com/jirka/gob.html",
					      maj, min, pl, VERSION);
			}

			if(effective_rmaj != effective_maj) {
				error_printf(GOB_ERROR, line_no,
					     "GOB major version %d required "
					     "(this is %s)\n"
					     "To upgrade your gob, see: "
					     "http://www.5z.com/jirka/gob.html",
					     effective_maj, VERSION);
			}

		}
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 489 "lexer.l"
{
			if(for_cpp) {
				error_printf(GOB_WARN, line_no,
					     "'%s' keyword should not "
					     "be used when generating "
					     "C++ code", yytext);
			}
			REJECT;
		}
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 499 "lexer.l"
{return FROM;}
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 500 "lexer.l"
{
			BEGIN(CLASS_STRING);
			before_string = CLASS_CODE;
			add_to_cbuf(yytext);
		}
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 505 "lexer.l"
{ add_to_cbuf(yytext); }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 506 "lexer.l"
{
			BEGIN(before_string);
			add_to_cbuf(yytext);
			yylval.id = cbuf->str;
			g_string_free (cbuf, FALSE);
			cbuf = NULL;
			return STRING;
		}
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 514 "lexer.l"
{ add_to_cbuf(yytext); }
	YY_BREAK
case 68:
/* rule 68 can match eol */
YY_RULE_SETUP
#line 515 "lexer.l"
{ add_to_cbuf(yytext); }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 517 "lexer.l"
{
			BEGIN(CLASS_STRING);
			before_string = CLASS_CODE_I;
			add_to_cbuf(yytext);
		}
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 523 "lexer.l"
{return VOID;}
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 524 "lexer.l"
{return STRUCT;}
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 525 "lexer.l"
{return UNION;}
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 526 "lexer.l"
{return ENUM;}
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 527 "lexer.l"
{return SIGNED;}
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 528 "lexer.l"
{return UNSIGNED;}
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 529 "lexer.l"
{return LONG;}
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 530 "lexer.l"
{return SHORT;}
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 531 "lexer.l"
{return INT;}
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 532 "lexer.l"
{return FLOAT;}
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 533 "lexer.l"
{return DOUBLE;}
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 534 "lexer.l"
{return CHAR;}
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 535 "lexer.l"
{return CONST;}
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 537 "lexer.l"
{return THREEDOTS;}
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 539 "lexer.l"
{yylval.line = line_no; return PUBLIC;}
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 540 "lexer.l"
{yylval.line = line_no; return PRIVATE;}
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 541 "lexer.l"
{yylval.line = line_no; return PROTECTED;}
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 542 "lexer.l"
{yylval.line = line_no; return CLASSWIDE;}
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 543 "lexer.l"
{yylval.line = line_no; return ARGUMENT;}
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 544 "lexer.l"
{yylval.line = line_no; return VIRTUAL;}
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 545 "lexer.l"
{yylval.line = line_no; return SIGNAL;}
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 546 "lexer.l"
{yylval.line = line_no; return OVERRIDE;}
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 547 "lexer.l"
{
				yylval.line = line_no;
				BEGIN(PROPERTY_CODE);
				return PROPERTY;
			}
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 552 "lexer.l"
{ yylval.line = line_no; return NICK; }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 553 "lexer.l"
{ yylval.line = line_no; return NAME; }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 554 "lexer.l"
{ yylval.line = line_no; return BLURB; }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 555 "lexer.l"
{ yylval.line = line_no; return MAXIMUM; }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 556 "lexer.l"
{ yylval.line = line_no; return MINIMUM; }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 557 "lexer.l"
{ yylval.line = line_no; return DEFAULT_VALUE; }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 558 "lexer.l"
{ yylval.line = line_no; return FLAGS; }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 559 "lexer.l"
{ yylval.line = line_no; return TYPE; }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 560 "lexer.l"
{ yylval.line = line_no; return FLAGS_TYPE; }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 561 "lexer.l"
{ yylval.line = line_no; return ENUM_TYPE; }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 562 "lexer.l"
{ yylval.line = line_no; return PARAM_TYPE; }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 563 "lexer.l"
{ yylval.line = line_no; return BOXED_TYPE; }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 564 "lexer.l"
{ yylval.line = line_no; return OBJECT_TYPE; }
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 565 "lexer.l"
{
		yylval.line = line_no;
		property_paren_depth = 1;
		BEGIN(PROPERTY_CODE_I);
		return '(';
			}
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 571 "lexer.l"
{
		yylval.line = line_no;
		property_paren_depth++;
		return '(';
			}
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 576 "lexer.l"
{
		yylval.line = line_no;
		property_paren_depth--;
		if (property_paren_depth == 0) {
			BEGIN(CLASS_CODE_I);
		}
		return ')';
			}
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 585 "lexer.l"
{
			yylval.id = g_strdup(yytext);
			return NUMBER;
		}
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 589 "lexer.l"
{
			/* This is cpp kind of token thingie */
			if (for_cpp) {
				yylval.id = g_strdup(yytext);
				return TOKEN;
			} else {
				REJECT;
			}
		}
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 598 "lexer.l"
{
			/* this one is for a classname with a namespace */
			yylval.id = g_strdup(yytext);
			return TYPETOKEN;
		}
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 603 "lexer.l"
{
			/* this is for a classname with an empty namespace */
			yylval.id = g_strdup(yytext);
			return TYPETOKEN;
		}
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 608 "lexer.l"
{
			yylval.id = g_strdup(yytext);
			return TOKEN;
		}
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 612 "lexer.l"
{
			yylval.id = g_strdup(yytext);
			return SINGLE_CHAR;
		}
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 617 "lexer.l"
{
			yylval.id = g_strdup(yytext);
			return ARRAY_DIM;
		}
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 621 "lexer.l"
{
			/* cheat for bitfield */
			yylval.id = g_strdup(yytext);
			return ARRAY_DIM;
		}
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 626 "lexer.l"
{
			BEGIN(CLASS_CODE_I);
			return '{';
		}
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 630 "lexer.l"
{
			BEGIN(C_CODE);
			parenth_depth=1;
			class_after_c = TRUE;
			yylval.line = line_no;
			clear_cbuf();
			ccode_line = line_no;
			return '{';
		}
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 639 "lexer.l"
{
				BEGIN(INITIAL);
				return '}';
			}
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 644 "lexer.l"
;  /*ignore*/
	YY_BREAK
case 121:
/* rule 121 can match eol */
YY_RULE_SETUP
#line 646 "lexer.l"
;  /*ignore*/
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 649 "lexer.l"
{
			yylval.line = line_no;
			return yytext[0];
		}
	YY_BREAK
case 123:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 654 "lexer.l"
{
			char *p;
			int t;
			p = strchr (yytext,'p');
			g_assert (p); /* we MUST have found it */
			sscanf (p, "prealloc %d", &t);
			prealloc=t;
		}
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 663 "lexer.l"
ECHO;
	YY_BREAK
#line 2498 "lexer.c"
			case YY_STATE_EOF(INITIAL):
			case YY_STATE_EOF(COMMENT):
			case YY_STATE_EOF(C_CODE):
			case YY_STATE_EOF(CODE_STRING):
			case YY_STATE_EOF(CLASS_CODE):
			case YY_STATE_EOF(CLASS_STRING):
			case YY_STATE_EOF(CLASS_CODE_I):
			case YY_STATE_EOF(PROPERTY_CODE):
			case YY_STATE_EOF(PROPERTY_CODE_I):
			case YY_STATE_EOF(GTK_DOC_BEFORE_NAME):
			case YY_STATE_EOF(GTK_DOC):
			case YY_STATE_EOF(GTK_DOC_LINE):
				yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			yy_size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			YY_FATAL_ERROR(
"input buffer overflow, can't enlarge buffer because scanner uses REJECT" );

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	(yy_state_ptr) = (yy_state_buf);
	*(yy_state_ptr)++ = yy_current_state;

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 570 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		*(yy_state_ptr)++ = yy_current_state;
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    
	register YY_CHAR yy_c = 1;
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 570 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 569);
	if ( ! yy_is_jam )
		*(yy_state_ptr)++ = yy_current_state;

		return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp )
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register yy_size_t number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			yy_size_t offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf  );

	yyfree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr )
{
    
	return yy_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, yy_size_t  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	yy_size_t i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
        
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
yy_size_t yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void yyset_lineno (int  line_number )
{
    
    yylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str )
{
        yyin = in_str ;
}

void yyset_out (FILE *  out_str )
{
        yyout = out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  bdebug )
{
        yy_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

    (yy_state_buf) = 0;
    (yy_state_ptr) = 0;
    (yy_full_match) = 0;
    (yy_lp) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    yyfree ( (yy_state_buf) );
    (yy_state_buf)  = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr )
{
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 663 "lexer.l"



